@@ -14,10 +14,15 @@ class EcoNameTranslator:
         self.failed = {}
     
     def translate(self,uncheckedNames):
+        print("Beginnging name reformatting")
         for item in uncheckedNames:
             self.index[item] = [cleanSingleSpeciesString(item),'']
+        print("Name reformatting complete")
+        print("Indexing records on taxonomy")
         self.tagInputWithTaxaLevel()
+        print("Expanding higher level taxonomic names")
         self.mapKnownTaxaLevelToSpecies()
+        print("Trying common name translation...(this may take a while)")
         self.tryCommonNameOnErrorCases()
         return self.index
     
