@@ -1,9 +1,8 @@
 import requests
-from higherLevelAPI import *
+from .higherLevelAPI import *
 import itertools
-from dataCleaning import *
-from dataCleaning import *
-from taxonomyAPI import *
+from .dataCleaning import *
+from .taxonomyAPI import *
 
 def commonNameAPI(bestEffortTuple):
     name, speciesResult = bestEffortTuple
